@@ -60,7 +60,7 @@ sub uploader_history_menu {
                 # Choose
                 my @indexes = choose(
                     $choices,
-                    { prompt => $prompt . "\n", layout => 3, index => 1, default => 1,
+                    { prompt => $prompt, layout => 3, index => 1, default => 1,
                         undef => '  BACK', no_spacebar => [ 0 .. $#pre ] }
                 );
                 if ( ! defined $indexes[0] || ! defined $choices->[$indexes[0]] ) {
